/*
 *  Copyright (c) 2008 Cyrille Berger <cberger@cberger.net>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation;
 * either version 2, or (at your option) any later version of the License.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef _GTLCORE_IMAGE_H_
#define _GTLCORE_IMAGE_H_

#include <GTLCore/BufferImage.h>

namespace GTLCore {
  class PixelDescription;
}

namespace GTLCore {
  /**
   * \ref Image is a convenient class inheriting \ref BufferImage and using a \ref GTLCore::Array
   * for the image data.
   * @ingroup GTLCore
   */
  class GTLCORE_EXPORT Image : public BufferImage {
      GTL_NO_COPY(Image);
    public:
      Image(int _width, int _height, const GTLCore::PixelDescription& _pixelDescription, const GTLCore::AbstractColorConverter* _colorConverter = 0 );
      ~Image();
    private:
      struct Private;
      Private* const d;
  };
};


#endif
